==> salutatoi_0.5.1.orig.tar.bz2: sat-0.5.1/frontends/src/quick_frontend/quick_utils.py <==
#!/usr/bin/python
# -*- coding: utf-8 -*-

# Primitivus: a SAT frontend
# Copyright (C) 2009, 2010, 2011, 2012, 2013, 2014 Jérôme Poisson (goffi@goffi.org)

# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.

# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.

# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from sat_frontends.tools.jid  import JID
from os.path import exists, splitext
from sat_frontends.quick_frontend.constants import Const

def escapePrivate(ori_jid):
    """Escape a private jid"""
    return JID(Const.PRIVATE_PREFIX + ori_jid.bare + '@' + ori_jid.resource)

def unescapePrivate(escaped_jid):
    if not escaped_jid.startswith(Const.PRIVATE_PREFIX):
        return escaped_jid
    escaped_split = tuple(escaped_jid[len(Const.PRIVATE_PREFIX):].split('@'))
    assert(len(escaped_split) == 3)
    return JID("%s@%s/%s" % escaped_split)

def getNewPath(path):
    """ Check if path exists, and find a non existant path if needed """
    idx = 2
    if not exists(path):
        return path
    root, ext = splitext(path)
    while True:
        new_path = "%s_%d%s" % (root, idx, ext)
        if not exists(new_path):
            return new_path
        idx+=1

==> salutatoi_0.6.1.orig.tar.bz2: sat-0.6.1/frontends/src/quick_frontend/quick_utils.py <==
#!/usr/bin/env python2
# -*- coding: utf-8 -*-

# Primitivus: a SAT frontend
# Copyright (C) 2009-2016 Jérôme Poisson (goffi@goffi.org)

# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.

# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.

# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from sat.core.i18n import _
from os.path import exists, splitext
from optparse import OptionParser

def getNewPath(path):
    """ Check if path exists, and find a non existant path if needed """
    idx = 2
    if not exists(path):
        return path
    root, ext = splitext(path)
    while True:
        new_path = "%s_%d%s" % (root, idx, ext)
        if not exists(new_path):
            return new_path
        idx+=1

def check_options():
    """Check command line options"""
    usage = _("""
    %prog [options]

    %prog --help for options list
    """)
    parser = OptionParser(usage=usage) # TODO: use argparse

    parser.add_option("-p", "--profile", help=_("Select the profile to use"))

    (options, args) = parser.parse_args()
    if options.profile:
        options.profile = options.profile.decode('utf-8')
    return options
